@@ -1,11 +1,7 @@
 /*
- * Copyright (c) 2020-2023, Stalwart Labs Ltd.
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
- * Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
- * https://www.apache.org/licenses/LICENSE-2.0> or the MIT license
- * <LICENSE-MIT or https://opensource.org/licenses/MIT>, at your
- * option. This file may not be copied, modified, or distributed
- * except according to those terms.
+ * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
 use std::time::SystemTime;
@@ -96,7 +92,7 @@ pub(super) struct SignableMessage<'a> {
     signature: &'a Signature,
 }
 
-impl<'a> Writable for SignableMessage<'a> {
+impl Writable for SignableMessage<'_> {
     fn write(self, writer: &mut impl Writer) {
         self.headers.write(writer);
         self.signature.write(writer, false);
@@ -110,17 +106,18 @@ pub mod test {
     use std::time::{Duration, Instant};
 
     use hickory_resolver::proto::op::ResponseCode;
-    use mail_parser::decoders::base64::base64_decode;
+    use mail_parser::{decoders::base64::base64_decode, MessageParser};
 
     use crate::{
         common::{
+            cache::test::DummyCaches,
             crypto::{Ed25519Key, RsaKey, Sha256},
             headers::HeaderIterator,
             parse::TxtRecordParser,
             verify::DomainKey,
         },
         dkim::{Atps, Canonicalization, DkimSigner, DomainKeyReport, HashAlgorithm, Signature},
-        AuthenticatedMessage, DkimOutput, DkimResult, Resolver,
+        AuthenticatedMessage, DkimOutput, DkimResult, MessageAuthenticator,
     };
 
     const RSA_PRIVATE_KEY: &str = include_str!("../../resources/rsa-private.pem");
@@ -192,6 +189,8 @@ pub mod test {
     ))]
     #[tokio::test]
     async fn dkim_sign_verify() {
+        use crate::common::cache::test::DummyCaches;
+
         let message = concat!(
             "From: bill@example.com\r\n",
             "To: jdoe@example.com\r\n",
@@ -233,25 +232,23 @@ pub mod test {
         .unwrap();
 
         // Create resolver
-        let resolver = Resolver::new_system_conf().unwrap();
-        #[cfg(any(test, feature = "test"))]
-        {
-            resolver.txt_add(
+        let resolver = MessageAuthenticator::new_system_conf().unwrap();
+        let caches = DummyCaches::new()
+            .with_txt(
                 "default._domainkey.example.com.".to_string(),
                 DomainKey::parse(RSA_PUBLIC_KEY.as_bytes()).unwrap(),
                 Instant::now() + Duration::new(3600, 0),
-            );
-            resolver.txt_add(
+            )
+            .with_txt(
                 "ed._domainkey.example.com.".to_string(),
                 DomainKey::parse(ED25519_PUBLIC_KEY.as_bytes()).unwrap(),
                 Instant::now() + Duration::new(3600, 0),
-            );
-            resolver.txt_add(
+            )
+            .with_txt(
                 "_report._domainkey.example.com.".to_string(),
                 DomainKeyReport::parse("ra=dkim-failures; rp=100; rr=x".as_bytes()).unwrap(),
                 Instant::now() + Duration::new(3600, 0),
             );
-        }
 
         dbg!("Test RSA-SHA256 relaxed/relaxed");
         #[cfg(feature = "rust-crypto")]
@@ -260,6 +257,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -275,6 +273,7 @@ pub mod test {
         dbg!("Test ED25519-SHA256 relaxed/relaxed");
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_ed)
                 .domain("example.com")
                 .selector("ed")
@@ -293,6 +292,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -312,6 +312,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -333,6 +334,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -359,6 +361,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify_with_opts(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -380,6 +383,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify_with_opts(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -401,6 +405,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -420,6 +425,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         let r = verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -444,6 +450,7 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -462,14 +469,14 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
-        #[cfg(any(test, feature = "test"))]
-        resolver.txt_add(
+        caches.txt_add(
             "UN42N5XOV642KXRXRQIYANHCOUPGQL5LT4WTBKYT2IJFLBWODFDQ._atps.example.com.".to_string(),
             Atps::parse(b"v=ATPS1;").unwrap(),
             Instant::now() + Duration::new(3600, 0),
         );
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -488,14 +495,14 @@ pub mod test {
         let pk_rsa = RsaKey::<Sha256>::from_pkcs1_pem(RSA_PRIVATE_KEY).unwrap();
         #[cfg(all(feature = "ring", not(feature = "rust-crypto")))]
         let pk_rsa = RsaKey::<Sha256>::from_rsa_pem(RSA_PRIVATE_KEY).unwrap();
-        #[cfg(any(test, feature = "test"))]
-        resolver.txt_add(
+        caches.txt_add(
             "example.com._atps.example.com.".to_string(),
             Atps::parse(b"v=ATPS1;").unwrap(),
             Instant::now() + Duration::new(3600, 0),
         );
         verify(
             &resolver,
+            &caches,
             DkimSigner::from_key(pk_rsa)
                 .domain("example.com")
                 .selector("default")
@@ -509,19 +516,27 @@ pub mod test {
         .await;
     }
 
-    pub async fn verify_with_opts<'x>(
-        resolver: &Resolver,
+    pub(crate) async fn verify_with_opts<'x>(
+        resolver: &MessageAuthenticator,
+        caches: &DummyCaches,
         signature: Signature,
         message_: &'x str,
         expect: Result<(), super::Error>,
         strict: bool,
     ) -> Vec<DkimOutput<'x>> {
-        let mut message = Vec::with_capacity(message_.len() + 100);
-        signature.write(&mut message, true);
-        message.extend_from_slice(message_.as_bytes());
+        let mut raw_message = Vec::with_capacity(message_.len() + 100);
+        signature.write(&mut raw_message, true);
+        raw_message.extend_from_slice(message_.as_bytes());
 
-        let message = AuthenticatedMessage::parse_with_opts(&message, strict).unwrap();
-        let dkim = resolver.verify_dkim(&message).await;
+        let message = AuthenticatedMessage::parse_with_opts(&raw_message, strict).unwrap();
+        assert_eq!(
+            message,
+            AuthenticatedMessage::from_parsed(
+                &MessageParser::new().parse(&raw_message).unwrap(),
+                strict
+            )
+        );
+        let dkim = resolver.verify_dkim(caches.parameters(&message)).await;
 
         match (dkim.last().unwrap().result(), &expect) {
             (DkimResult::Pass, Ok(_)) => (),
@@ -542,12 +557,13 @@ pub mod test {
             .collect()
     }
 
-    pub async fn verify<'x>(
-        resolver: &Resolver,
+    pub(crate) async fn verify<'x>(
+        resolver: &MessageAuthenticator,
+        caches: &DummyCaches,
         signature: Signature,
         message_: &'x str,
         expect: Result<(), super::Error>,
     ) -> Vec<DkimOutput<'x>> {
-        verify_with_opts(resolver, signature, message_, expect, true).await
+        verify_with_opts(resolver, caches, signature, message_, expect, true).await
     }
 }
